@@ -10,6 +10,7 @@ import (
 	"github.com/goreleaser/goreleaser/v2/internal/client"
 	"github.com/goreleaser/goreleaser/v2/internal/git"
 	"github.com/goreleaser/goreleaser/v2/internal/golden"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe"
 	"github.com/goreleaser/goreleaser/v2/internal/skips"
 	"github.com/goreleaser/goreleaser/v2/internal/testctx"
 	"github.com/goreleaser/goreleaser/v2/internal/testlib"
@@ -51,6 +52,7 @@ func createTemplateData() templateData {
 		},
 		License: "MIT",
 		Version: "0.1.3",
+		Install: "./testdata/install.sh",
 		Package: `# bin
 		install -Dm755 "./goreleaser" "${pkgdir}/usr/bin/goreleaser"
 
@@ -181,6 +183,7 @@ func TestFullPipe(t *testing.T) {
 				ctx.Config.AURs[0].OptDepends = []string{"wget: stuff", "foo: bar"}
 				ctx.Config.AURs[0].Provides = []string{"git", "svn"}
 				ctx.Config.AURs[0].Conflicts = []string{"libcurl", "cvs", "blah"}
+				ctx.Config.AURs[0].Install = "./testdata/install.sh"
 			},
 		},
 		"default-gitlab": {
@@ -389,6 +392,7 @@ func TestRunPipe(t *testing.T) {
 					IDs:         []string{"foo"},
 					GitURL:      url,
 					PrivateKey:  key,
+					Install:     "./testdata/install.sh",
 				},
 			},
 			GitHubURLs: config.GitHubURLs{
@@ -494,7 +498,11 @@ func TestRunPipe(t *testing.T) {
 	require.NoError(t, runAll(ctx, client))
 	require.NoError(t, Pipe{}.Publish(ctx))
 
-	requireEqualRepoFiles(t, folder, ".", "foo", url)
+	requireEqualRepoFilesMap(t, ".", url, map[string]string{
+		"PKGBUILD":    filepath.Join(folder, "aur", "foo-bin.pkgbuild"),
+		".SRCINFO":    filepath.Join(folder, "aur", "foo-bin.srcinfo"),
+		"foo.install": "./testdata/install.sh",
+	})
 }
 
 func TestRunPipeMultipleConfigurations(t *testing.T) {
@@ -507,6 +515,9 @@ func TestRunPipeMultipleConfigurations(t *testing.T) {
 			Dist:        folder,
 			ProjectName: "foo",
 			AURs: []config.AUR{
+				{
+					Disable: "true",
+				},
 				{
 					Name:        "foo",
 					IDs:         []string{"foo"},
@@ -566,7 +577,7 @@ func TestRunPipeMultipleConfigurations(t *testing.T) {
 	client := client.NewMock()
 
 	require.NoError(t, Pipe{}.Default(ctx))
-	require.NoError(t, runAll(ctx, client))
+	require.True(t, pipe.IsSkip(runAll(ctx, client)), "should partial skip")
 	require.NoError(t, Pipe{}.Publish(ctx))
 
 	dir := t.TempDir()
@@ -868,19 +879,16 @@ func TestSkip(t *testing.T) {
 	})
 }
 
-func requireEqualRepoFiles(tb testing.TB, distDir, repoDir, name, url string) {
+func requireEqualRepoFilesMap(tb testing.TB, repoDir, url string, files map[string]string) {
 	tb.Helper()
 	dir := tb.TempDir()
 	_, err := git.Run(testctx.New(), "-C", dir, "clone", url, "repo")
 	require.NoError(tb, err)
 
-	for reponame, ext := range map[string]string{
-		"PKGBUILD": ".pkgbuild",
-		".SRCINFO": ".srcinfo",
-	} {
-		path := filepath.Join(distDir, "aur", name+"-bin"+ext)
-		bts, err := os.ReadFile(path)
+	for reponame, distpath := range files {
+		bts, err := os.ReadFile(distpath)
 		require.NoError(tb, err)
+		ext := filepath.Ext(distpath)
 		golden.RequireEqualExt(tb, bts, ext)
 
 		bts, err = os.ReadFile(filepath.Join(dir, "repo", repoDir, reponame))
@@ -888,3 +896,11 @@ func requireEqualRepoFiles(tb testing.TB, distDir, repoDir, name, url string) {
 		golden.RequireEqualExt(tb, bts, ext)
 	}
 }
+
+func requireEqualRepoFiles(tb testing.TB, distDir, repoDir, name, url string) {
+	tb.Helper()
+	requireEqualRepoFilesMap(tb, repoDir, url, map[string]string{
+		"PKGBUILD": filepath.Join(distDir, "aur", name+"-bin.pkgbuild"),
+		".SRCINFO": filepath.Join(distDir, "aur", name+"-bin.srcinfo"),
+	})
+}
