@@ -11,7 +11,7 @@ type ErrDirty struct {
 }
 
 func (e ErrDirty) Error() string {
-	return fmt.Sprintf("git is currently in a dirty state\nPlease check in your pipeline what can be changing the following files:\n%v\nLearn more at https://goreleaser.com/errors/dirty\n", e.status)
+	return fmt.Sprintf("git is in a dirty state\nPlease check in your pipeline what can be changing the following files:\n%v\nLearn more at https://goreleaser.com/errors/dirty\n", e.status)
 }
 
 // ErrWrongRef happens when the HEAD reference is different from the tag being built.
@@ -25,7 +25,7 @@ func (e ErrWrongRef) Error() string {
 
 // ErrNoTag happens if the underlying git repository doesn't contain any tags
 // but no snapshot-release was requested.
-var ErrNoTag = errors.New("git doesn't contain any tags. Either add a tag or use --snapshot")
+var ErrNoTag = errors.New("git doesn't contain any tags - either add a tag or use --snapshot")
 
 // ErrNotRepository happens if you try to run goreleaser against a folder
 // which is not a git repository.
