@@ -23,7 +23,7 @@ func TestAnnounceInvalidTemplate(t *testing.T) {
 	ctx := testctx.NewWithCfg(config.Project{
 		Announce: config.Announce{
 			Teams: config.Teams{
-				Enabled:         true,
+				Enabled:         "true",
 				MessageTemplate: "{{ .Foo }",
 			},
 		},
@@ -35,7 +35,7 @@ func TestAnnounceMissingEnv(t *testing.T) {
 	ctx := testctx.NewWithCfg(config.Project{
 		Announce: config.Announce{
 			Teams: config.Teams{
-				Enabled: true,
+				Enabled: "true",
 			},
 		},
 	})
@@ -45,17 +45,21 @@ func TestAnnounceMissingEnv(t *testing.T) {
 
 func TestSkip(t *testing.T) {
 	t.Run("skip", func(t *testing.T) {
-		require.True(t, Pipe{}.Skip(testctx.New()))
+		skip, err := Pipe{}.Skip(testctx.New())
+		require.NoError(t, err)
+		require.True(t, skip)
 	})
 
 	t.Run("dont skip", func(t *testing.T) {
 		ctx := testctx.NewWithCfg(config.Project{
 			Announce: config.Announce{
 				Teams: config.Teams{
-					Enabled: true,
+					Enabled: "true",
 				},
 			},
 		})
-		require.False(t, Pipe{}.Skip(ctx))
+		skip, err := Pipe{}.Skip(ctx)
+		require.NoError(t, err)
+		require.False(t, skip)
 	})
 }
